unit AppEvents;

interface

uses
  SysUtils, Windows, Messages, Classes, Graphics, Controls, Forms, Dialogs,
  DsgnIntf;

type

  TDuplicateError = class(Exception);

  TApplicationEvents = class(TComponent)
  private
     FOnActivate: TNotifyEvent;
     FOnDeactivate: TNotifyEvent;
     FOnHelp: THelpEvent;
     FOnHint: TNotifyEvent;
     FOnIdle: TIdleEvent;
     FOnMessage: TMessageEvent;
     FOnMinimize: TNotifyEvent;
     FOnRestore: TNotifyEvent;
     FOnException: TExceptionEvent;
     FOnShowHint: TShowHintEvent;

  protected
  public
     constructor Create(AOwner: TComponent); override;
     destructor  Destroy; override;
     procedure   Loaded;  override;
  published
     property OnActivate: TNotifyEvent
        read FOnActivate write FOnActivate;
     property OnDeactivate: TNotifyEvent
        read FOnDeactivate write FOnDeactivate;
     property OnHelp: THelpEvent
        read FOnHelp write FOnHelp;
     property OnHint: TNotifyEvent
        read FOnHint write FOnHint;
     property OnIdle: TIdleEvent
        read FOnIdle write FOnIdle;
     property OnMessage: TMessageEvent
        read FOnMessage write FOnMessage;
     property OnMinimize: TNotifyEvent
        read FOnMinimize write FOnMinimize;
     property OnRestore: TNotifyEvent
        read FOnRestore write FOnRestore;
     property OnException: TExceptionEvent
        read FOnException write FOnException;
     property OnShowHint: TShowHintEvent
        read FOnShowHint write FOnShowHint;
  end;

procedure Register;

implementation

const
  ComponentCounter: Integer = 0;
  CRLF = #13#10;


procedure Register;
begin
  RegisterComponents('AddOn', [TApplicationEvents]);
end;


constructor TApplicationEvents.Create(AOwner: TComponent);
begin
  // the following makes sure that there is one and only one Application component
  Inc(ComponentCounter );
  if ComponentCounter > 1 then
     raise TDuplicateError.Create( 'You can have one and only one' + CRLF +
                                   'TApplicationEvents component' + CRLF +
                                   'in a project' );
  inherited Create(AOwner);
end;


destructor TApplicationEvents.Destroy;
begin
  inherited Destroy;
  Dec(ComponentCounter);
end;


procedure TApplicationEvents.Loaded;
begin
  if Assigned( FOnActivate ) then
     Application.OnActivate := FOnActivate;
  if Assigned( FOnDeactivate ) then
     Application.OnDeactivate := FOnDeactivate;
  if Assigned( FOnHelp ) then
     Application.OnHelp := FOnHelp;
  if Assigned( FOnHint ) then
     Application.OnHint := FOnHint;
  if Assigned( FOnIdle ) then
     Application.OnIdle := FOnIdle;
  if Assigned( FOnMessage ) then
     Application.OnMessage := FOnMessage;
  if Assigned( FOnMinimize ) then
     Application.OnMinimize := FOnMinimize;
  if Assigned( FOnRestore ) then
     Application.OnRestore := FOnRestore;
  if Assigned( FOnException ) then
     Application.OnException := FOnException;
  if Assigned( FOnShowHint ) then
     Application.OnShowHint := FOnShowHint;
end;

end.

